@@ -33,10 +33,10 @@ pd.set_option('display.max_rows', 100)
 ## COMMAND LINE INTERFACE
 
 @click.group()
-@click.version_option("76.7.7", package_name="alacorder")
+@click.version_option("76.8.3", package_name="alacorder")
 def cli():
     """
-    ALACORDER beta 76.7
+    ALACORDER beta 76.8
 
     Alacorder processes case detail PDFs into data tables suitable for research purposes. Alacorder also generates compressed text archives from the source PDFs to speed future data collection from the same set of cases.
 
@@ -623,7 +623,7 @@ def party_search(driver, name = "", party_type = "", ssn="", dob="", county="",
                 continue
     return pdflinks
 
-def downloadPDF(driver, url, speed=1, no_log=False):
+def downloadPDF(driver, url, speed=1, no_log=False, cID="", uID="", pwd=""):
     if driver.current_url == "https://v2.alacourt.com/frmlogin.aspx":
         login(driver, cID, uID, pwd, speed, no_log)
     a = driver.get(url)
